﻿/*
 * FCKeditor - The text editor for internet
 * Copyright (C) 2003-2006 Frederico Caldeira Knabben
 * 
 * Licensed under the terms of the GNU Lesser General Public License:
 * 		http://www.opensource.org/licenses/lgpl-license.php
 * 
 * For further information visit:
 * 		http://www.fckeditor.net/
 * 
 * "Support Open Source software. What about a donation today?"
 * 
 * File Name: de.js
 * 	German language file.
 * 
 * File Authors:
 * 		Maik Unruh (m.unruh@mm-concept.de)
 * 		Hendrik Kramer (HK@lwd.de)
 */

var FCKLang =
{
// Language direction : "ltr" (left to right) or "rtl" (right to left).
Dir					: "ltr",

ToolbarCollapse		: "Symbolleiste einklappen",
ToolbarExpand		: "Symbolleiste ausklappen",

// Toolbar Items and Context Menu
Save				: "Speichern",
NewPage				: "Neue Seite",
Preview				: "Vorschau",
Cut					: "Ausschneiden",
Copy				: "Kopieren",
Paste				: "Einfügen",
PasteText			: "aus Textdatei einfügen",
PasteWord			: "aus MS-Word einfügen",
Print				: "Drucken",
SelectAll			: "Alles auswählen",
RemoveFormat		: "Formatierungen entfernen",
InsertLinkLbl		: "Link",
InsertLink			: "Link einfügen/editieren",
RemoveLink			: "Link entfernen",
Anchor				: "Anker einfügen/editieren",
InsertImageLbl		: "Bild",
InsertImage			: "Bild einfügen/editieren",
InsertFlashLbl		: "Flash",
InsertFlash			: "Flash einfügen/editieren",
InsertTableLbl		: "Tabelle",
InsertTable			: "Tabelle einfügen/editieren",
InsertLineLbl		: "Linie",
InsertLine			: "Horizontale Linie einfügen",
InsertSpecialCharLbl: "Sonderzeichen",
InsertSpecialChar	: "Sonderzeichen einfügen/editieren",
InsertSmileyLbl		: "Smiley",
InsertSmiley		: "Smiley einfügen",
About				: "Über FCKeditor",
Bold				: "Fett",
Italic				: "Kursiv",
Underline			: "Unterstrichen",
StrikeThrough		: "Durchgestrichen",
Subscript			: "Tiefgestellt",
Superscript			: "Hochgestellt",
LeftJustify			: "Linksbündig",
CenterJustify		: "Zentriert",
RightJustify		: "Rechtsbündig",
BlockJustify		: "Blocksatz",
DecreaseIndent		: "Einzug verringern",
IncreaseIndent		: "Einzug erhöhen",
Undo				: "Rückgängig",
Redo				: "Wiederherstellen",
NumberedListLbl		: "Nummerierte Liste",
NumberedList		: "Nummerierte Liste einfügen/entfernen",
BulletedListLbl		: "Liste",
BulletedList		: "Liste einfügen/entfernen",
ShowTableBorders	: "Zeige Tabellenrahmen",
ShowDetails			: "Zeige Details",
Style				: "Style",
FontFormat			: "Format",
Font				: "Schriftart",
FontSize			: "Size",
TextColor			: "Textfarbe",
BGColor				: "Hintergrundfarbe",
Source				: "Quellcode",
Find				: "Finden",
Replace				: "Ersetzen",
SpellCheck			: "Rechtschreibprüfung",
UniversalKeyboard	: "Universal-Tastatur",
PageBreakLbl		: "Seitenumbruch",
PageBreak			: "Seitenumbruch einfügen",

Form			: "Formular",
Checkbox		: "Checkbox",
RadioButton		: "Radiobutton",
TextField		: "Textfeld einzeilig",
Textarea		: "Textfeld mehrzeilig",
HiddenField		: "verstecktes Feld",
Button			: "Klickbutton",
SelectionField	: "Auswahlfeld",
ImageButton		: "Bildbutton",

FitWindow		: "Editor maximieren",

// Context Menu
EditLink			: "Link editieren",
CellCM				: "Zelle",
RowCM				: "Zeile",
ColumnCM			: "Spalte",
InsertRow			: "Zeile einfügen",
DeleteRows			: "Zeile entfernen",
InsertColumn		: "Spalte einfügen",
DeleteColumns		: "Spalte löschen",
InsertCell			: "Zelle einfügen",
DeleteCells			: "Zelle löschen",
MergeCells			: "Zellen vereinen",
SplitCell			: "Zelle teilen",
TableDelete			: "Tabelle löschen",
CellProperties		: "Zellen Eigenschaften",
TableProperties		: "Tabellen Eigenschaften",
ImageProperties		: "Bild Eigenschaften",
FlashProperties		: "Flash Eigenschaften",

AnchorProp			: "Anker Eigenschaften",
ButtonProp			: "Button Eigenschaften",
CheckboxProp		: "Checkbox Eigenschaften",
HiddenFieldProp		: "Verstecktes Feld Eigenschaften",
RadioButtonProp		: "Optionsfeld Eigenschaften",
ImageButtonProp		: "Bildbutton Eigenschaften",
TextFieldProp		: "Textfeld (einzeilig) Eigenschaften",
SelectionFieldProp	: "Auswahlfeld Eigenschaften",
TextareaProp		: "Textfeld (mehrzeilig) Eigenschaften",
FormProp			: "Formular Eigenschaften",

FontFormats			: "Normal;Formatiert;Addresse;Überschrift 1;Überschrift 2;Überschrift 3;Überschrift 4;Überschrift 5;Überschrift 6;Normal (DIV)",

// Alerts and Messages
ProcessingXHTML		: "Bearbeite XHTML. Bitte warten...",
Done				: "Fertig",
PasteWordConfirm	: "Der Text, den Sie einfügen möchten, scheint aus MS-Word kopiert zu sein. Möchten Sie ihn zuvor bereinigen lassen?",
NotCompatiblePaste	: "Diese Funktion steht nur im Internet Explorer ab Version 5.5 zur Verfügung. Möchten Sie den Text unbereinigt einfügen?",
UnknownToolbarItem	: "Unbekanntes Menüleisten-Objekt \"%1\"",
UnknownCommand		: "Unbekannter Befehl \"%1\"",
NotImplemented		: "Befehl nicht implementiert",
UnknownToolbarSet	: "Menüleiste \"%1\" existiert nicht",
NoActiveX			: "Die Sicherheitseinstellungen Ihres Browsers beschränken evtl. einige Funktionen des Editors. Aktivieren Sie die Option \"ActiveX-Steuerelemente und Plugins ausführen\" in den Sicherheitseinstellungen, um diese Funktionen nutzen zu können",
BrowseServerBlocked : "Ein Auswahlfenster konnte nicht geöffnet werden. Stellen Sie sicher, das alle Popup-Blocker ausgeschaltet sind.",
DialogBlocked		: "Das Dialog-Fenster konnte nicht geöffnet werden. Stellen Sie sicher, das alle Popup-Blocker ausgeschaltet sind.",

// Dialogs
DlgBtnOK			: "OK",
DlgBtnCancel		: "Abbrechen",
DlgBtnClose			: "Schließen",
DlgBtnBrowseServer	: "Server durchsuchen",
DlgAdvancedTag		: "Erweitert",
DlgOpOther			: "<andere>",
DlgInfoTab			: "Info",
DlgAlertUrl			: "Bitte tragen Sie die URL ein",

// General Dialogs Labels
DlgGenNotSet		: "< nichts >",
DlgGenId			: "ID",
DlgGenLangDir		: "Schreibrichtung",
DlgGenLangDirLtr	: "Links nach Rechts (LTR)",
DlgGenLangDirRtl	: "Rechts nach Links (RTL)",
DlgGenLangCode		: "Sprachenkürzel",
DlgGenAccessKey		: "Schlüssel",
DlgGenName			: "Name",
DlgGenTabIndex		: "Tab Index",
DlgGenLongDescr		: "Langform URL",
DlgGenClass			: "Stylesheet Klasse",
DlgGenTitle			: "Titel Beschreibung",
DlgGenContType		: "Content Beschreibung",
DlgGenLinkCharset	: "Ziel-Zeichensatz",
DlgGenStyle			: "Style",

// Image Dialog
DlgImgTitle			: "Bild Eigenschaften",
DlgImgInfoTab		: "Bild-Info",
DlgImgBtnUpload		: "Zum Server senden",
DlgImgURL			: "Bildauswahl",
DlgImgUpload		: "Upload",
DlgImgAlt			: "Alternativer Text",
DlgImgWidth			: "Breite",
DlgImgHeight		: "Höhe",
DlgImgLockRatio		: "Größenverhältniss beibehalten",
DlgBtnResetSize		: "Größe zurücksetzen",
DlgImgBorder		: "Rahmen",
DlgImgHSpace		: "H-Abstand",
DlgImgVSpace		: "V-Abstand",
DlgImgAlign			: "Ausrichtung",
DlgImgAlignLeft		: "Links",
DlgImgAlignAbsBottom: "Abs Unten",
DlgImgAlignAbsMiddle: "Abs Mitte",
DlgImgAlignBaseline	: "Baseline",
DlgImgAlignBottom	: "Unten",
DlgImgAlignMiddle	: "Mitte",
DlgImgAlignRight	: "Rechts",
DlgImgAlignTextTop	: "Text Oben",
DlgImgAlignTop		: "Oben",
DlgImgPreview		: "Vorschau",
DlgImgAlertUrl		: "Bitte geben Sie die Bild-URL an",
DlgImgLinkTab		: "Link",

// Flash Dialog
DlgFlashTitle		: "Flash Eigenschaften",
DlgFlashChkPlay		: "autom. Abspielen",
DlgFlashChkLoop		: "Endlosschleife",
DlgFlashChkMenu		: "Flash-Menü aktivieren",
DlgFlashScale		: "Skalierung",
DlgFlashScaleAll	: "Alles anzeigen",
DlgFlashScaleNoBorder	: "ohne Rand",
DlgFlashScaleFit	: "Passgenau",

// Link Dialog
DlgLnkWindowTitle	: "Link",
DlgLnkInfoTab		: "Link Info",
DlgLnkTargetTab		: "Zielseite",

DlgLnkType			: "Link-Typ",
DlgLnkTypeURL		: "URL",
DlgLnkTypeAnchor	: "Anker in dieser Seite",
DlgLnkTypeEMail		: "E-Mail",
DlgLnkProto			: "Protokoll",
DlgLnkProtoOther	: "<anderes>",
DlgLnkURL			: "URL",
DlgLnkAnchorSel		: "Anker auswählen",
DlgLnkAnchorByName	: "nach Anker Name",
DlgLnkAnchorById	: "nach Element Id",
DlgLnkNoAnchors		: "<keine Anker im Dokument vorhanden>",
DlgLnkEMail			: "E-Mail Addresse",
DlgLnkEMailSubject	: "Betreffzeile",
DlgLnkEMailBody		: "Nachrichtentext",
DlgLnkUpload		: "Upload",
DlgLnkBtnUpload		: "Zum Server senden",

DlgLnkTarget		: "Zielseite",
DlgLnkTargetFrame	: "<Frame>",
DlgLnkTargetPopup	: "<Pop-up Fenster>",
DlgLnkTargetBlank	: "Neues Fenster (_blank)",
DlgLnkTargetParent	: "Oberes Fenster (_parent)",
DlgLnkTargetSelf	: "Gleiches Fenster (_self)",
DlgLnkTargetTop		: "Oberstes Fenster (_top)",
DlgLnkTargetFrameName	: "Ziel-Fenster Name",
DlgLnkPopWinName	: "Pop-up Fenster Name",
DlgLnkPopWinFeat	: "Pop-up Fenster Eigenschaften",
DlgLnkPopResize		: "Vergrößerbar",
DlgLnkPopLocation	: "Adress-Leiste",
DlgLnkPopMenu		: "Menü-Leiste",
DlgLnkPopScroll		: "Rollbalken",
DlgLnkPopStatus		: "Statusleiste",
DlgLnkPopToolbar	: "Werkzeugleiste",
DlgLnkPopFullScrn	: "Vollbild (IE)",
DlgLnkPopDependent	: "Abhängig (Netscape)",
DlgLnkPopWidth		: "Breite",
DlgLnkPopHeight		: "Höhe",
DlgLnkPopLeft		: "Linke Position",
DlgLnkPopTop		: "Obere Position",

DlnLnkMsgNoUrl		: "Bitte geben Sie die Link-URL an",
DlnLnkMsgNoEMail	: "Bitte geben Sie e-Mail Adresse an",
DlnLnkMsgNoAnchor	: "Bitte wählen Sie einen Anker aus",
DlnLnkMsgInvPopName	: "Der Name des Popups muss mit einem Buchstaben beginnen und darf keine Leerzeichen enthalten",

// Color Dialog
DlgColorTitle		: "Farbauswahl",
DlgColorBtnClear	: "Keine Farbe",
DlgColorHighlight	: "Vorschau",
DlgColorSelected	: "Ausgewählt",

// Smiley Dialog
DlgSmileyTitle		: "Smiley auswählen",

// Special Character Dialog
DlgSpecialCharTitle	: "Sonderzeichen auswählen",

// Table Dialog
DlgTableTitle		: "Tabellen Eigenschaften",
DlgTableRows		: "Zeile",
DlgTableColumns		: "Spalte",
DlgTableBorder		: "Rahmen",
DlgTableAlign		: "Ausrichtung",
DlgTableAlignNotSet	: "<nichts>",
DlgTableAlignLeft	: "Links",
DlgTableAlignCenter	: "Zentriert",
DlgTableAlignRight	: "Rechts",
DlgTableWidth		: "Breite",
DlgTableWidthPx		: "Pixel",
DlgTableWidthPc		: "%",
DlgTableHeight		: "Höhe",
DlgTableCellSpace	: "Zellenabstand außen",
DlgTableCellPad		: "Zellenabstand innen",
DlgTableCaption		: "Überschrift",
DlgTableSummary		: "Inhaltsübersicht",

// Table Cell Dialog
DlgCellTitle		: "Zellen-Eigenschaften",
DlgCellWidth		: "Breite",
DlgCellWidthPx		: "Pixel",
DlgCellWidthPc		: "%",
DlgCellHeight		: "Höhe",
DlgCellWordWrap		: "Umbruch",
DlgCellWordWrapNotSet	: "<nichts>",
DlgCellWordWrapYes	: "Ja",
DlgCellWordWrapNo	: "Nein",
DlgCellHorAlign		: "Horizontale Ausrichtung",
DlgCellHorAlignNotSet	: "<nichts>",
DlgCellHorAlignLeft	: "Links",
DlgCellHorAlignCenter	: "Zentriert",
DlgCellHorAlignRight: "Rechts",
DlgCellVerAlign		: "Vertikale Ausrichtung",
DlgCellVerAlignNotSet	: "<nichts>",
DlgCellVerAlignTop	: "Oben",
DlgCellVerAlignMiddle	: "Mitte",
DlgCellVerAlignBottom	: "Unten",
DlgCellVerAlignBaseline	: "Grundlinie",
DlgCellRowSpan		: "Zeilen zusammenfassen",
DlgCellCollSpan		: "Spalten zusammenfassen",
DlgCellBackColor	: "Hintergrundfarbe",
DlgCellBorderColor	: "Rahmenfarbe",
DlgCellBtnSelect	: "Auswahl...",

// Find Dialog
DlgFindTitle		: "Finden",
DlgFindFindBtn		: "Finden",
DlgFindNotFoundMsg	: "Der gesuchte Text wurde nicht gefunden.",

// Replace Dialog
DlgReplaceTitle			: "Ersetzen",
DlgReplaceFindLbl		: "Suche nach:",
DlgReplaceReplaceLbl	: "Ersetze mit:",
DlgReplaceCaseChk		: "Groß-Kleinschreibung beachten",
DlgReplaceReplaceBtn	: "Ersetzen",
DlgReplaceReplAllBtn	: "Alle Ersetzen",
DlgReplaceWordChk		: "Nur ganze Worte suchen",

// Paste Operations / Dialog
PasteErrorPaste	: "Die Sicherheitseinstellungen Ihres Browsers lassen es nicht zu, den Text automatisch einzufügen. Bitte benutzen Sie die System-Zwischenablage über STRG-C (kopieren) und STRG-V (einfügen).",
PasteErrorCut	: "Die Sicherheitseinstellungen Ihres Browsers lassen es nicht zu, den Text automatisch auszuschneiden. Bitte benutzen Sie die System-Zwischenablage über STRG-X (ausschneiden) und STRG-V (einfügen).",
PasteErrorCopy	: "Die Sicherheitseinstellungen Ihres Browsers lassen es nicht zu, den Text automatisch kopieren. Bitte benutzen Sie die System-Zwischenablage über STRG-C (kopieren).",

PasteAsText		: "Als Text einfügen",
PasteFromWord	: "Aus Word einfügen",

DlgPasteMsg2	: "Bitte fügen Sie den Text in der folgenden Box über die Tastatur (mit <STRONG>Ctrl+V</STRONG>) ein und bestätigen Sie mit <STRONG>OK</STRONG>.",
DlgPasteIgnoreFont		: "Ignoriere Schriftart-Definitionen",
DlgPasteRemoveStyles	: "Entferne Style-Definitionen",
DlgPasteCleanBox		: "Inhalt aufräumen",

// Color Picker
ColorAutomatic	: "Automatisch",
ColorMoreColors	: "Weitere Farben...",

// Document Properties
DocProps		: "Dokument Eigenschaften",

// Anchor Dialog
DlgAnchorTitle		: "Anker Eigenschaften",
DlgAnchorName		: "Anker Name",
DlgAnchorErrorName	: "Bitte geben Sie den Namen des Ankers ein",

// Speller Pages Dialog
DlgSpellNotInDic		: "Nicht im Wörterbuch",
DlgSpellChangeTo		: "Ändern in",
DlgSpellBtnIgnore		: "Ignorieren",
DlgSpellBtnIgnoreAll	: "Alle Ignorieren",
DlgSpellBtnReplace		: "Ersetzen",
DlgSpellBtnReplaceAll	: "Alle Ersetzen",
DlgSpellBtnUndo			: "Rückgängig",
DlgSpellNoSuggestions	: " - keine Vorschläge - ",
DlgSpellProgress		: "Rechtschreibprüfung läuft...",
DlgSpellNoMispell		: "Rechtschreibprüfung abgeschlossen - keine Fehler gefunden",
DlgSpellNoChanges		: "Rechtschreibprüfung abgeschlossen - keine Worte geändert",
DlgSpellOneChange		: "Rechtschreibprüfung abgeschlossen - ein Wort geändert",
DlgSpellManyChanges		: "Rechtschreibprüfung abgeschlossen - %1 Wörter geändert",

IeSpellDownload			: "Rechtschreibprüfung nicht installiert. Möchten Sie sie jetzt herunterladen?",

// Button Dialog
DlgButtonText		: "Text (Wert)",
DlgButtonType		: "Typ",
DlgButtonTypeBtn	: "Button",
DlgButtonTypeSbm	: "Absenden",
DlgButtonTypeRst	: "Zurücksetzen",

// Checkbox and Radio Button Dialogs
DlgCheckboxName		: "Name",
DlgCheckboxValue	: "Wert",
DlgCheckboxSelected	: "ausgewählt",

// Form Dialog
DlgFormName		: "Name",
DlgFormAction	: "Action",
DlgFormMethod	: "Method",

// Select Field Dialog
DlgSelectName		: "Name",
DlgSelectValue		: "Wert",
DlgSelectSize		: "Größe",
DlgSelectLines		: "Linien",
DlgSelectChkMulti	: "Erlaube Mehrfachauswahl",
DlgSelectOpAvail	: "Mögliche Optionen",
DlgSelectOpText		: "Text",
DlgSelectOpValue	: "Wert",
DlgSelectBtnAdd		: "Hinzufügen",
DlgSelectBtnModify	: "Ändern",
DlgSelectBtnUp		: "Hoch",
DlgSelectBtnDown	: "Runter",
DlgSelectBtnSetValue : "Setze als Standardwert",
DlgSelectBtnDelete	: "Entfernen",

// Textarea Dialog
DlgTextareaName	: "Name",
DlgTextareaCols	: "Spalten",
DlgTextareaRows	: "Reihen",

// Text Field Dialog
DlgTextName			: "Name",
DlgTextValue		: "Wert",
DlgTextCharWidth	: "Zeichenbreite",
DlgTextMaxChars		: "Max. Zeichen",
DlgTextType			: "Typ",
DlgTextTypeText		: "Text",
DlgTextTypePass		: "Passwort",

// Hidden Field Dialog
DlgHiddenName	: "Name",
DlgHiddenValue	: "Wert",

// Bulleted List Dialog
BulletedListProp	: "Listen-Eigenschaften",
NumberedListProp	: "Nummerierte Listen-Eigenschaften",
DlgLstStart			: "Start",
DlgLstType			: "Typ",
DlgLstTypeCircle	: "Ring",
DlgLstTypeDisc		: "Kreis",
DlgLstTypeSquare	: "Quadrat",
DlgLstTypeNumbers	: "Nummern (1, 2, 3)",
DlgLstTypeLCase		: "Kleinbuchstaben (a, b, c)",
DlgLstTypeUCase		: "Großbuchstaben (A, B, C)",
DlgLstTypeSRoman	: "Kleine römische Zahlen (i, ii, iii)",
DlgLstTypeLRoman	: "Große römische Zahlen (I, II, III)",

// Document Properties Dialog
DlgDocGeneralTab	: "Allgemein",
DlgDocBackTab		: "Hintergrund",
DlgDocColorsTab		: "Farben und Abstände",
DlgDocMetaTab		: "Metadaten",

DlgDocPageTitle		: "Seitentitel",
DlgDocLangDir		: "Schriftrichtung",
DlgDocLangDirLTR	: "Links nach Rechts",
DlgDocLangDirRTL	: "rechts nach Links",
DlgDocLangCode		: "Sprachkürzel",
DlgDocCharSet		: "Zeichenkodierung",
DlgDocCharSetCE		: "Zentraleuropäisch",
DlgDocCharSetCT		: "traditionell Chinesisch (Big5)",
DlgDocCharSetCR		: "Kyrillisch",
DlgDocCharSetGR		: "Griechisch",
DlgDocCharSetJP		: "Japanisch",
DlgDocCharSetKR		: "Koreanisch",
DlgDocCharSetTR		: "Türkisch",
DlgDocCharSetUN		: "Unicode (UTF-8)",
DlgDocCharSetWE		: "Westeuropäisch",
DlgDocCharSetOther	: "Andere Zeichenkodierung",

DlgDocDocType		: "Dokumententyp",
DlgDocDocTypeOther	: "Anderer Dokumententyp",
DlgDocIncXHTML		: "Beziehe XHTML Deklarationen ein",
DlgDocBgColor		: "Hintergrundfarbe",
DlgDocBgImage		: "Hintergrundbild URL",
DlgDocBgNoScroll	: "feststehender Hintergrund",
DlgDocCText			: "Text",
DlgDocCLink			: "Link",
DlgDocCVisited		: "Besuchter Link",
DlgDocCActive		: "Aktiver Link",
DlgDocMargins		: "Seitenränder",
DlgDocMaTop			: "Oben",
DlgDocMaLeft		: "Links",
DlgDocMaRight		: "Rechts",
DlgDocMaBottom		: "Unten",
DlgDocMeIndex		: "Schlüsselwörter (durch Komma getrennt)",
DlgDocMeDescr		: "Dokument-Beschreibung",
DlgDocMeAuthor		: "Autor",
DlgDocMeCopy		: "Copyright",
DlgDocPreview		: "Vorschau",

// Templates Dialog
Templates			: "Vorlagen",
DlgTemplatesTitle	: "Vorlagen",
DlgTemplatesSelMsg	: "Klicken Sie auf eine Vorlage, um sie im Editor zu öffnen (der aktuelle Inhalt wird dabei gelöscht!):",
DlgTemplatesLoading	: "Liste der Vorlagen wird geladen. Bitte warten...",
DlgTemplatesNoTpl	: "(keine Vorlagen definiert)",
DlgTemplatesReplace	: "Aktuellen Inhalt ersetzen",

// About Dialog
DlgAboutAboutTab	: "Über",
DlgAboutBrowserInfoTab	: "Browser-Info",
DlgAboutLicenseTab	: "Lizenz",
DlgAboutVersion		: "Version",
DlgAboutLicense		: "Lizensiert unter den Richtlinien der GNU Lesser General Public License",
DlgAboutInfo		: "Für weitere Informationen siehe"
}